@@ -551,11 +551,13 @@ function sb_execve_postprocess_native_executable(rule, exec_policy,
 	return 1, mapped_file, filename, #argv, argv, #envp, envp
 end
 
-if string.match(sbox_cputransparency_cmd, "qemu") then
-	cputransparency_method_is_qemu = true
-end
-if string.match(sbox_cputransparency_cmd, "sbrsh") then
-	cputransparency_method_is_sbrsh = true
+for k, v in pairs({conf_cputransparency_target, conf_cputransparency_native}) do
+	if (v ~= nil and string.match(v.cmd, "qemu")) then
+		v.method_is_qemu = true
+	end
+	if (v ~= nil and string.match(v.cmd, "sbrsh")) then
+		v.method_is_sbrsh = true
+	end
 end
 
 function split_to_tokens(text,delim)
@@ -696,28 +698,28 @@ function sb_execve_postprocess_sbrsh(rule, exec_policy,
 end
 
 function sb_execve_postprocess_cpu_transparency_executable(rule, exec_policy,
-    exec_type, mapped_file, filename, argv, envp)
+    exec_type, mapped_file, filename, argv, envp, conf_cputransparency)
 
 	sb.log("debug", "postprocessing cpu_transparency for " .. filename)
 
-	if cputransparency_method_is_qemu then
+	if conf_cputransparency.method_is_qemu then
 		local new_envp = {}
 		local new_argv = {}
 		local new_filename
 
-		if conf_cputransparency_qemu_argv == nil then
-			table.insert(new_argv, sbox_cputransparency_cmd)
-			new_filename = sbox_cputransparency_cmd
+		if conf_cputransparency.qemu_argv == nil then
+			table.insert(new_argv, conf_cputransparency.cmd)
+			new_filename = conf_cputransparency.cmd
 		else
-			for i = 1, table.maxn(conf_cputransparency_qemu_argv) do
-				table.insert(new_argv, conf_cputransparency_qemu_argv[i])
+			for i = 1, table.maxn(conf_cputransparency.qemu_argv) do
+				table.insert(new_argv, conf_cputransparency.qemu_argv[i])
 			end
-			new_filename = conf_cputransparency_qemu_argv[1]
+			new_filename = conf_cputransparency.qemu_argv[1]
 		end
 
-		if conf_cputransparency_qemu_env ~= nil then
-			for i = 1, table.maxn(conf_cputransparency_qemu_env) do
-				table.insert(new_envp, conf_cputransparency_qemu_env[i])
+		if conf_cputransparency.qemu_env ~= nil then
+			for i = 1, table.maxn(conf_cputransparency.qemu_env) do
+				table.insert(new_envp, conf_cputransparency.qemu_env[i])
 			end
 		end
 
@@ -725,13 +727,13 @@ function sb_execve_postprocess_cpu_transparency_executable(rule, exec_policy,
 		table.insert(new_argv, "-L")
 		table.insert(new_argv, "/")
 
-		if conf_cputransparency_has_argv0_flag then
+		if conf_cputransparency.has_argv0_flag then
 			-- set target argv[0]
 			table.insert(new_argv, "-0")
 			table.insert(new_argv, argv[1])
 		end
 
-		if conf_cputransparency_qemu_has_libattr_hack_flag then
+		if conf_cputransparency.qemu_has_libattr_hack_flag then
 			-- For ARM emulation:
 			-- a nasty bug exists in some older libattr library
 			-- version (e.g. it causes "ls -l" to crash), this
@@ -746,7 +748,7 @@ function sb_execve_postprocess_cpu_transparency_executable(rule, exec_policy,
 			needs_libfakeroot = true
 		end
 
-		if conf_cputransparency_qemu_has_env_control_flags then
+		if conf_cputransparency.qemu_has_env_control_flags then
 			for i = 1, #envp do
 				-- drop LD_TRACE_* from target environment
 				if string.match(envp[i], "^LD_TRACE_.*") then
@@ -793,15 +795,15 @@ function sb_execve_postprocess_cpu_transparency_executable(rule, exec_policy,
 		-- Fortunately that is easy: 
 		local qemu_ldlibpath
 		local qemu_ldpreload
-		if conf_cputransparency_qemu_ld_library_path == "" then
+		if conf_cputransparency.qemu_ld_library_path == "" then
 			qemu_ldlibpath = "LD_LIBRARY_PATH=" .. host_ld_library_path
 		else
-			qemu_ldlibpath = conf_cputransparency_qemu_ld_library_path
+			qemu_ldlibpath = conf_cputransparency.qemu_ld_library_path
 		end
-		if conf_cputransparency_qemu_ld_preload == "" then
+		if conf_cputransparency.qemu_ld_preload == "" then
 			qemu_ldpreload = "LD_PRELOAD=" ..  host_ld_preload
 		else
-			qemu_ldpreload = conf_cputransparency_qemu_ld_preload
+			qemu_ldpreload = conf_cputransparency.qemu_ld_preload
 		end
 
 		-- NOTE/FIXME: This still assumes that the name of the libfakeroot
@@ -832,7 +834,7 @@ function sb_execve_postprocess_cpu_transparency_executable(rule, exec_policy,
 		-- environment&args were changed
 		return 0, new_filename, filename, #new_argv, new_argv,
 			#new_envp, new_envp
-	elseif cputransparency_method_is_sbrsh then
+	elseif conf_cputransparency.method_is_sbrsh then
 		return sb_execve_postprocess_sbrsh(rule, exec_policy,
     			exec_type, mapped_file, filename, argv, envp)
 	end
@@ -890,8 +892,13 @@ function sb_execve_postprocess(rule, exec_policy, exec_type,
 	elseif (exec_type == "cpu_transparency") then
 		return sb_execve_postprocess_cpu_transparency_executable(rule,
 			exec_policy, exec_type, mapped_file,
-			filename, argv, envp)
+			filename, argv, envp, conf_cputransparency_target)
 	elseif (exec_type == "static") then
+		if (conf_cputransparency_native ~= nil and conf_cputransparency_native.cmd ~= "") then
+			return sb_execve_postprocess_cpu_transparency_executable(rule,
+				exec_policy, exec_type, mapped_file,
+				filename, argv, envp, conf_cputransparency_native)
+		end
 		-- [see comment in sb_exec.c]
 		local ldlibpath
 		local ldpreload
